### Name: calcLWCompactScore
### Title: Scoring functions for redistricting.
### Aliases: calcLWCompactScore calcPopScore calcRangeScore calcGroupScore
###   calcReockScore calcHolesScore calcMomentScore calcContiguityScore
### Keywords: IO spatial optimize models distribution

### ** Examples

  # read in a shapefile with demographic data
  suffolk.map <- importBardShape(
    system.file("shapefiles/suffolk_tracts.shp", package="BARD"))
  ndists<-5
  
  # create some initial plans
  kplan <- createKmeansPlan(suffolk.map,ndists)
  rplan <- createRandomPlan(suffolk.map,ndists)
  wkplan<-createWeightedKmeansPlan(suffolk.map,ndists,weightVar="POP")
  
  calcPopScore(kplan)
  calcPopScore(rplan)
  calcLWCompactScore(kplan)
  calcLWCompactScore(rplan)
  calcLWCompactScore(kplan)
  calcContiguityScore(rplan)
  calcContiguityScore(kplan)
  calcRangeScore(kplan)
  calcRangeScore(rplan)
  calcRangeScore(kplan, targrange=c(.01,.99))
  calcRangeScore(rplan, targrange=c(.01,.99))
  calcGroupScore(kplan,groups=list(c(1:10),c(100:120)),penalties=c(1,2))
  calcGroupScore(rplan,groups=list(c(1:10),c(100:120)),penalties=c(1,2))
  kplan2<-kplan1<-kplan
  cl<-cbind(c(318,320),c(kplan1[318],kplan1[320]))
 
  if ( ! all(calcPopScore(kplan2,lastscore=calcPopScore(kplan1),changelist=cl) == calcPopScore(kplan2))) {
        warning("dynamic score does not match!")
  }
    
  calcPopScore(kplan,predvar="POP")
  calcPopScore(wkplan,predvar="POP")
  calcMomentScore(kplan)
  calcMomentScore(wkplan)
  calcMomentScore(kplan,weightVar="POP")
  calcMomentScore(wkplan,weightVar="POP")




